aboutsummaryrefslogtreecommitdiffstats
path: root/cmd/utils
diff options
context:
space:
mode:
authorWei-Ning Huang <w@dexon.org>2018-10-24 18:59:48 +0800
committerWei-Ning Huang <w@dexon.org>2019-03-12 12:19:09 +0800
commitd4f73229104ee8f12737ce5b3da4c9360d02dbeb (patch)
treecfe0626288a7c36300791ac1f5d1843e5114f7ee /cmd/utils
parent08720a6cc45e2ce975b8284d91b2ebe9e40b46f7 (diff)
downloaddexon-d4f73229104ee8f12737ce5b3da4c9360d02dbeb.tar.gz
dexon-d4f73229104ee8f12737ce5b3da4c9360d02dbeb.tar.zst
dexon-d4f73229104ee8f12737ce5b3da4c9360d02dbeb.zip
Rename geth -> gdex and fix Dockerfile
Diffstat (limited to 'cmd/utils')
-rw-r--r--cmd/utils/flags.go10
1 files changed, 5 insertions, 5 deletions
diff --git a/cmd/utils/flags.go b/cmd/utils/flags.go
index 33c8f83b7..e814044d7 100644
--- a/cmd/utils/flags.go
+++ b/cmd/utils/flags.go
@@ -603,7 +603,7 @@ var (
MetricsInfluxDBDatabaseFlag = cli.StringFlag{
Name: "metrics.influxdb.database",
Usage: "InfluxDB database name to push reported metrics to",
- Value: "geth",
+ Value: "gdex",
}
MetricsInfluxDBUsernameFlag = cli.StringFlag{
Name: "metrics.influxdb.username",
@@ -852,7 +852,7 @@ func MakeAddress(ks *keystore.KeyStore, account string) (accounts.Account, error
log.Warn("-------------------------------------------------------------------")
log.Warn("Referring to accounts by order in the keystore folder is dangerous!")
log.Warn("This functionality is deprecated and will be removed in the future!")
- log.Warn("Please use explicit addresses! (can search via `geth account list`)")
+ log.Warn("Please use explicit addresses! (can search via `gdex account list`)")
log.Warn("-------------------------------------------------------------------")
accs := ks.Accounts()
@@ -1319,7 +1319,7 @@ func SetupMetrics(ctx *cli.Context) {
log.Info("Enabling metrics export to InfluxDB")
- go influxdb.InfluxDBWithTags(metrics.DefaultRegistry, 10*time.Second, endpoint, database, username, password, "geth.", tagsMap)
+ go influxdb.InfluxDBWithTags(metrics.DefaultRegistry, 10*time.Second, endpoint, database, username, password, "gdex.", tagsMap)
}
}
}
@@ -1437,11 +1437,11 @@ func MakeConsolePreloads(ctx *cli.Context) []string {
// This is a temporary function used for migrating old command/flags to the
// new format.
//
// e.g. geth account new --keystore /tmp/mykeystore --lightkdf
//
// is equivalent after calling this method with:
//
// geth --keystore /tmp/mykeystore --lightkdf account new
//
// This allows the use of the existing configuration functionality.
// When all flags are migrated this function can be removed and the existing
@@ -1437,11 +1437,11 @@ func MakeConsolePreloads(ctx *cli.Context) []string {
// new format.
//
-// e.g. geth account new --keystore /tmp/mykeystore --lightkdf
+// e.g. gdex account new --keystore /tmp/mykeystore --lightkdf
//
// is equivalent after calling this method with:
@@ -1437,11 +1437,11 @@ func MakeConsolePreloads(ctx *cli.Context) []string {
// is equivalent after calling this method with:
//
-// geth --keystore /tmp/mykeystore --lightkdf account new
+// gdex --keystore /tmp/mykeystore --lightkdf account new
//
// This allows the use of the existing configuration functionality.